=== modified file 'client/drizzle.cc'
--- client/drizzle.cc	2011-03-11 12:09:47 +0000
+++ client/drizzle.cc	2011-03-14 11:43:13 +0000
@@ -2204,7 +2204,6 @@
     return(0);
   if (status.getAddToHistory() && line[0] && not_in_history(line))
     add_history(line);
-  char *end_of_line=line+(uint32_t) strlen(line);
 
   for (pos=out=line ; (inchar= (unsigned char) *pos) ; pos++)
   {
@@ -2298,37 +2297,6 @@
         continue;
       }
     }
-    else if (!*ml_comment && !*in_string &&
-             (end_of_line - pos) >= 10 &&
-             !strncmp(pos, "delimiter ", 10))
-    {
-      // Flush previously accepted characters
-      if (out != line)
-      {
-        buffer->append(line, (out - line));
-        out= line;
-      }
-
-      // Flush possible comments in the buffer
-      if (!buffer->empty())
-      {
-        if (com_go(buffer, 0) > 0) // < 0 is not fatal
-          return(1);
-        assert(buffer!=NULL);
-        buffer->clear();
-      }
-
-      /*
-        Delimiter wants the get rest of the given line as argument to
-        allow one to change ';' to ';;' and back
-      */
-      buffer->append(pos);
-      if (com_delimiter(buffer, pos) > 0)
-        return(1);
-
-      buffer->clear();
-      break;
-    }
     else if (!*ml_comment && !*in_string && !strncmp(pos, delimiter,
                                                      strlen(delimiter)))
     {
@@ -2388,8 +2356,23 @@
 
       // comment to end of line
       if (preserve_comments)
+      {
+        bool started_with_nothing= !buffer->empty();
         buffer->append(pos);
 
+        /*
+          A single-line comment by itself gets sent immediately so that
+          client commands (delimiter, status, etc) will be interpreted on
+          the next line.
+        */
+        if (started_with_nothing)
+        {
+          if (com_go(buffer, 0) > 0)             // < 0 is not fatal
+           return 1;
+          buffer->clear();
+        }
+      }  
+
       break;
     }
     else if (!*in_string && inchar == '/' && *(pos+1) == '*' &&

=== modified file 'configure.ac'
--- configure.ac	2011-03-07 16:42:18 +0000
+++ configure.ac	2011-03-14 17:01:01 +0000
@@ -26,7 +26,7 @@
 
 PANDORA_CANONICAL_TARGET(less-warnings, require-cxx, force-gcc42, version-from-vc) 
 
-LIBDRIZZLE_LIBRARY_VERSION=1:0:0
+LIBDRIZZLE_LIBRARY_VERSION=2:0:1
 #                          | | |
 #                   +------+ | +---+
 #                   |        |     |
@@ -41,6 +41,9 @@
 #                      changed
 AC_SUBST(LIBDRIZZLE_LIBRARY_VERSION)
 
+libdrizzleincludedir='${includedir}/libdrizzle-1.0'
+AC_SUBST(libdrizzleincludedir)
+
 # libdrizzle versioning when linked with GNU ld.
 AS_IF([test "$lt_cv_prog_gnu_ld" = "yes"],[
   LD_VERSION_SCRIPT="-Wl,--version-script=\$(top_srcdir)/config/drizzle.ver"
@@ -156,7 +159,7 @@
  tests/Makefile dnl
  drizzled/plugin/version.h dnl
  support-files/drizzle7.pc dnl
- support-files/libdrizzle.pc dnl
+ support-files/libdrizzle-1.0.pc dnl
  support-files/smf/install.sh dnl
  support-files/smf/drizzle.xml dnl
  support-files/smf/drizzle)

=== modified file 'docs/analyze.rst'
--- docs/analyze.rst	2011-03-08 03:47:42 +0000
+++ docs/analyze.rst	2011-03-12 16:21:40 +0000
@@ -5,7 +5,7 @@
 
 .. code-block:: mysql
 
-	ANALYZE TABLE table_name [, table_name] ...
+	ANALYZE [LOCAL | NO_WRITE_TO_BINLOG] TABLE tbl_name [, tbl_name] 
 
 ANALYZE TABLE usually read locks a table, and then analyzes and stores
 the key distribution for a table.

=== modified file 'docs/functions/control_flow.rst'
--- docs/functions/control_flow.rst	2011-02-23 14:17:23 +0000
+++ docs/functions/control_flow.rst	2011-03-12 16:21:40 +0000
@@ -10,6 +10,9 @@
 
 Control flow functions return a value for each row processed, which represents the result of the comparison or condition specified. They can be used in ``SELECT``, ``WHERE``, ``ORDER BY``, and ``GROUP BY`` statements.
 
+CASE
+----
+
 There are two basic examples of the ``CASE`` statment:
 
  1. ::
@@ -25,3 +28,52 @@
 In this version, if [condition] is true, result is returned. If nothing is matched, the result after ``ELSE`` is returned, or ``NULL`` is returned if there is no ``ELSE`` part.
 
 When [condition] is for equal comparison (=), this example syntax returns the same result as the first example.
+
+IF/ELSE
+---------
+
+This type of control flow function checks IF a condition is satisfied (i.e. the Boolean expression returns TRUE), the IF SQL statement will execute. IF the condition is not satisfied (i.e. the Boolean expression returns FALSE), the ELSE SQL statement is executed.
+
+Syntax for IF/ELSE: ::
+
+	IF ( Boolean_expression ) 
+	BEGIN
+	SQL statement
+	END
+	ELSE
+	BEGIN
+	SQL statement
+	END
+
+
+IFNULL
+-------
+
+Given IFNULL(arg1,arg2), if arg1 is not NULL, IFNULL() returns arg1; it otherwise returns arg2. IFNULL() returns a numeric or string value, depending on how it's used. ::
+
+.. code-block:: mysql
+
+	SELECT IFNULL(2,0);
+        -> 2
+	
+	SELECT IFNULL(NULL,1);
+        -> 1
+	
+	SELECT IFNULL(1/0,10);
+        -> 10
+	
+	SELECT IFNULL(1/0,'yes');
+        -> 'yes'
+
+NULLIF
+-------
+
+NULLIF(arg1,arg2) returns NULL if arg1 = arg2 is true, otherwise returns arg1. ::
+
+.. code-block:: mysql
+
+	SELECT NULLIF(1,1);
+	-> NULL
+
+	SELECT NULLIF(1,2);
+        -> 1

=== modified file 'docs/functions/current_time_functions.rst'
--- docs/functions/current_time_functions.rst	2011-02-23 13:08:09 +0000
+++ docs/functions/current_time_functions.rst	2011-03-11 15:54:41 +0000
@@ -53,14 +53,14 @@
 now()	                            
 ------
 
-NOW returns the current date and time. The return value will be expressed as 'YYYY-MM-DD HH:MM:SS' or YYYYMMDDHHMMSS.uuuuuu, depending on whether the function is used in a string or numeric context. The value is expressed in the current time zone.
+NOW returns the current date and time. The return value will be expressed as 'YYYY-MM-DD HH:MM:SS:mmmmmm' or YYYYMMDDHHMMSS.uuuuuu, depending on whether the function is used in a string or numeric context. The value is expressed in the current time zone.
 
 .. code-block:: mysql
 
 	SELECT NOW();
-        	-> '2011-02-15 13:40:06'
+        	-> '2011-02-15 13:40:06:002203'
 	SELECT NOW() + 0;
-        	-> 20110215134006.000000
+        	-> 20110215134006.002203
 
 NOW returns a constant time that indicates the time at which the statement began to execute. 
 
@@ -70,11 +70,11 @@
 
 Returns:
 
-+---------------------+----------+---------------------+
-| NOW()               | SLEEP(2) | NOW()               |
-+=====================+==========+=====================+
-| 2011-02-20 20:15:09 |        0 | 2011-02-20 20:15:09 |
-+---------------------+----------+---------------------+
++----------------------------+----------+----------------------------+
+| NOW()                      | SLEEP(2) | NOW()                      |
++============================+==========+============================+
+| 2011-02-20 20:15:09:002203 |        0 | 2011-02-20 20:15:09:002203 |
++----------------------------+----------+----------------------------+
 
 SYSDATE, however, returns the exact time at which the function was invoked.
 

=== modified file 'docs/functions/date_trunc.rst'
--- docs/functions/date_trunc.rst	2011-02-22 03:25:57 +0000
+++ docs/functions/date_trunc.rst	2011-03-11 15:54:41 +0000
@@ -1,2 +1,30 @@
 DATE TRUNC
-===========
\ No newline at end of file
+===========
+
+DATE_TRUNC truncates a date to a specified precision. The idea is similar to the trunc function for numbers.
+
+The syntax is: date_trunc(text, source)
+
+Valid values for *text* are:
+
+* microseconds
+* milliseconds
+* second
+* minute
+* hour
+* day
+* week
+* month
+* quarter
+* year
+* decade
+* century
+* millennium
+
+In this example, 'source' is a TIMESTAMP value with microsecond precision:
+
+.. code-block:: mysql
+
+	date_trunc('hour', timestamp '2011-02-26 10:35:44:712005')
+
+Returns: 2011-02-26 10:00:00

=== modified file 'docs/mysql_differences.rst'
--- docs/mysql_differences.rst	2011-02-21 01:35:37 +0000
+++ docs/mysql_differences.rst	2011-03-14 20:37:50 +0000
@@ -181,18 +181,6 @@
  * SET NAMES
  * Multi-table delete and multi-table update code was removed and can be accomplished through subqueries. More detailed information can be found in the :doc:`dml` section.
 
-Operators Removed
------------------
-
-Bit operators
- * &&
- * >>
- * <<
- * ~
- * ^
- * '|'
- * &
-
 Removed functions
 -----------------
 
@@ -203,9 +191,6 @@
 Keywords removed
 ----------------
 
- * BIT_AND
- * BIT_OR
- * BIT_XOR
  * CIPHER
  * CLIENT
  * CODE

=== modified file 'docs/orderby.rst'
--- docs/orderby.rst	2011-02-15 22:03:42 +0000
+++ docs/orderby.rst	2011-03-11 15:54:41 +0000
@@ -44,6 +44,8 @@
 | 2 	  | Roberts    | Teri 	  |21 Brown  | Chicago|
 +---------+------------+----------+----------+--------+
 
+Without using "ORDERBY" in the following query, the result-set will be non-deterministic, and could returned matching rows in a different order for each query. 
+
 ORDER BY DESC can be used to reverse the order of the result set.
 
 .. code-block:: mysql
@@ -51,9 +53,6 @@
 	SELECT * FROM Persons
 	ORDER BY LastName DESC;
 
-.. todo::
-
-   add something about SELECT * without ORDER BY being non-deterministic
 
 .. todo::
 

=== modified file 'drizzled/cached_item.cc'
--- drizzled/cached_item.cc	2011-02-24 19:13:33 +0000
+++ drizzled/cached_item.cc	2011-03-14 16:41:31 +0000
@@ -26,6 +26,7 @@
 
 #include <config.h>
 #include <drizzled/cached_item.h>
+#include <drizzled/field.h>
 #include <drizzled/sql_string.h>
 #include <drizzled/session.h>
 #include <drizzled/item/field.h>

=== modified file 'drizzled/cursor.cc'
--- drizzled/cursor.cc	2011-03-10 12:49:38 +0000
+++ drizzled/cursor.cc	2011-03-14 16:41:31 +0000
@@ -43,6 +43,7 @@
 #include <drizzled/sql_parse.h>
 #include <drizzled/transaction_services.h>
 #include <drizzled/key.h>
+#include <drizzled/sql_lex.h>
 
 using namespace std;
 

=== modified file 'drizzled/field_iterator.cc'
--- drizzled/field_iterator.cc	2011-03-10 12:49:38 +0000
+++ drizzled/field_iterator.cc	2011-03-14 16:41:31 +0000
@@ -21,6 +21,7 @@
 #include <drizzled/field_iterator.h>
 #include <drizzled/table_list.h>
 #include <drizzled/session.h>
+#include <drizzled/sql_lex.h>
 #include <drizzled/table.h>
 
 namespace drizzled
@@ -46,11 +47,7 @@
 
 Item *Field_iterator_table::create_item(Session *session)
 {
-  Select_Lex *select= session->lex().current_select;
-
-  Item_field *item= new Item_field(session, &select->context, *ptr);
-
-  return item;
+  return new Item_field(session, &session->lex().current_select->context, *ptr);
 }
 
 

=== modified file 'drizzled/function/func.cc'
--- drizzled/function/func.cc	2011-03-03 08:29:06 +0000
+++ drizzled/function/func.cc	2011-03-14 16:41:31 +0000
@@ -28,6 +28,7 @@
 #include <drizzled/field/int64.h>
 #include <drizzled/field/size.h>
 #include <drizzled/function/math/int.h>
+#include <drizzled/item/field.h>
 #include <drizzled/session.h>
 #include <drizzled/sql_list.h>
 #include <drizzled/sql_string.h>

=== modified file 'drizzled/function/get_system_var.cc'
--- drizzled/function/get_system_var.cc	2011-03-10 12:49:38 +0000
+++ drizzled/function/get_system_var.cc	2011-03-14 16:41:31 +0000
@@ -23,9 +23,9 @@
 #include <drizzled/function/get_system_var.h>
 #include <drizzled/session.h>
 #include <drizzled/sys_var.h>
+#include <drizzled/sql_lex.h>
 
-namespace drizzled
-{
+namespace drizzled {
 
 Item_func_get_system_var::
 Item_func_get_system_var(sys_var *var_arg, sql_var_t var_type_arg,

=== modified file 'drizzled/function/set_user_var.cc'
--- drizzled/function/set_user_var.cc	2011-03-03 08:29:06 +0000
+++ drizzled/function/set_user_var.cc	2011-03-14 16:41:31 +0000
@@ -24,9 +24,9 @@
 #include <drizzled/session.h>
 #include <drizzled/plugin/client.h>
 #include <drizzled/user_var_entry.h>
+#include <drizzled/table.h>
 
-namespace drizzled
-{
+namespace drizzled {
 
 /*
   When a user variable is updated (in a SET command or a query like

=== modified file 'drizzled/function/time/from_unixtime.cc'
--- drizzled/function/time/from_unixtime.cc	2011-02-17 00:14:13 +0000
+++ drizzled/function/time/from_unixtime.cc	2011-03-14 16:41:31 +0000
@@ -24,6 +24,7 @@
 #include <drizzled/session.h>
 #include <drizzled/temporal.h>
 #include <drizzled/time_functions.h>
+#include <drizzled/field.h>
 
 #include <sstream>
 #include <string>

=== modified file 'drizzled/function/time/now.cc'
--- drizzled/function/time/now.cc	2011-02-17 00:14:13 +0000
+++ drizzled/function/time/now.cc	2011-03-14 16:41:31 +0000
@@ -22,11 +22,10 @@
 #include <drizzled/function/time/now.h>
 #include <drizzled/current_session.h>
 #include <drizzled/session.h>
-
 #include <drizzled/temporal.h>
+#include <drizzled/field.h>
 
-namespace drizzled
-{
+namespace drizzled {
 
 String *Item_func_now::val_str(String *)
 {

=== modified file 'drizzled/function/time/sysdate_local.cc'
--- drizzled/function/time/sysdate_local.cc	2011-02-17 00:14:13 +0000
+++ drizzled/function/time/sysdate_local.cc	2011-03-14 16:41:31 +0000
@@ -22,9 +22,9 @@
 #include <drizzled/function/time/sysdate_local.h>
 #include <drizzled/tztime.h>
 #include <drizzled/session.h>
+#include <drizzled/field.h>
 
-namespace drizzled
-{
+namespace drizzled {
 
 /**
     Converts current time in time_t to type::Time represenatation for local

=== modified file 'drizzled/function/time/unix_timestamp.cc'
--- drizzled/function/time/unix_timestamp.cc	2011-02-17 00:14:13 +0000
+++ drizzled/function/time/unix_timestamp.cc	2011-03-14 16:41:31 +0000
@@ -22,11 +22,10 @@
 #include <drizzled/function/time/unix_timestamp.h>
 #include <drizzled/field/epoch.h>
 #include <drizzled/session.h>
-
 #include <drizzled/temporal.h>
+#include <drizzled/item/field.h>
 
-namespace drizzled
-{
+namespace drizzled {
 
 int64_t Item_func_unix_timestamp::val_int()
 {

=== modified file 'drizzled/item.cc'
--- drizzled/item.cc	2011-03-10 12:49:38 +0000
+++ drizzled/item.cc	2011-03-14 16:41:31 +0000
@@ -53,6 +53,7 @@
 #include <drizzled/internal/m_string.h>
 #include <drizzled/item/ref.h>
 #include <drizzled/item/subselect.h>
+#include <drizzled/sql_lex.h>
 
 #include <cstdio>
 #include <math.h>

=== modified file 'drizzled/item/cmpfunc.cc'
--- drizzled/item/cmpfunc.cc	2011-03-12 15:07:12 +0000
+++ drizzled/item/cmpfunc.cc	2011-03-14 16:41:31 +0000
@@ -36,6 +36,7 @@
 #include <drizzled/sql_select.h>
 #include <drizzled/temporal.h>
 #include <drizzled/time_functions.h>
+#include <drizzled/sql_lex.h>
 
 #include <math.h>
 #include <algorithm>

=== modified file 'drizzled/item/field.cc'
--- drizzled/item/field.cc	2011-03-10 12:49:38 +0000
+++ drizzled/item/field.cc	2011-03-14 16:41:31 +0000
@@ -30,6 +30,7 @@
 #include <drizzled/item/outer_ref.h>
 #include <drizzled/plugin/client.h>
 #include <drizzled/item/subselect.h>
+#include <drizzled/sql_lex.h>
 
 #include <boost/dynamic_bitset.hpp>
 

=== modified file 'drizzled/item/ref.cc'
--- drizzled/item/ref.cc	2011-03-10 12:49:38 +0000
+++ drizzled/item/ref.cc	2011-03-14 16:41:31 +0000
@@ -26,9 +26,9 @@
 #include <drizzled/plugin/client.h>
 #include <drizzled/item/sum.h>
 #include <drizzled/item/subselect.h>
+#include <drizzled/sql_lex.h>
 
-namespace drizzled
-{
+namespace drizzled {
 
 Item_ref::Item_ref(Name_resolution_context *context_arg,
                    Item **item, const char *table_name_arg,

=== modified file 'drizzled/item/subselect.cc'
--- drizzled/item/subselect.cc	2011-03-10 12:49:38 +0000
+++ drizzled/item/subselect.cc	2011-03-14 16:41:31 +0000
@@ -45,9 +45,9 @@
 #include <drizzled/select_max_min_finder_subselect.h>
 #include <drizzled/select_exists_subselect.h>
 #include <drizzled/select_union.h>
+#include <drizzled/sql_lex.h>
 
-namespace drizzled
-{
+namespace drizzled {
 
 extern plugin::StorageEngine *myisam_engine;
 

=== modified file 'drizzled/item/sum.cc'
--- drizzled/item/sum.cc	2011-03-10 12:49:38 +0000
+++ drizzled/item/sum.cc	2011-03-14 16:41:31 +0000
@@ -40,13 +40,13 @@
 #include <drizzled/type/decimal.h>
 #include <drizzled/internal/m_string.h>
 #include <drizzled/item/subselect.h>
+#include <drizzled/sql_lex.h>
 
 #include <algorithm>
 
 using namespace std;
 
-namespace drizzled
-{
+namespace drizzled {
 
 extern plugin::StorageEngine *heap_engine;
 

=== modified file 'drizzled/join.cc'
--- drizzled/join.cc	2011-03-10 12:49:38 +0000
+++ drizzled/join.cc	2011-03-14 16:41:31 +0000
@@ -64,6 +64,7 @@
 #include <drizzled/debug.h>
 #include <drizzled/item/subselect.h>
 #include <drizzled/my_hash.h>
+#include <drizzled/sql_lex.h>
 #include <algorithm>
 
 using namespace std;

=== modified file 'drizzled/lookup_symbol.cc'
--- drizzled/lookup_symbol.cc	2011-03-10 11:16:26 +0000
+++ drizzled/lookup_symbol.cc	2011-03-14 16:41:31 +0000
@@ -24,6 +24,7 @@
 #include <drizzled/sql_base.h>
 #include <drizzled/lookup_symbol.h>
 #include <drizzled/comp_creator.h>
+#include <drizzled/sql_lex.h>
 
 #include <drizzled/lex_symbol.h>
 #include <drizzled/function_hash.h>

=== modified file 'drizzled/main.cc'
--- drizzled/main.cc	2011-03-10 12:49:38 +0000
+++ drizzled/main.cc	2011-03-14 16:41:31 +0000
@@ -69,6 +69,7 @@
 #include <drizzled/current_session.h>
 #include <drizzled/daemon.h>
 #include <drizzled/sql_base.h>
+#include <drizzled/sql_lex.h>
 
 using namespace drizzled;
 using namespace std;

=== modified file 'drizzled/message/schema.cc'
--- drizzled/message/schema.cc	2011-02-17 00:14:13 +0000
+++ drizzled/message/schema.cc	2011-03-14 16:41:31 +0000
@@ -26,6 +26,7 @@
 #include <drizzled/show.h>
 #include <drizzled/message/schema.h>
 #include <drizzled/session.h>
+#include <drizzled/charset_info.h>
 
 #include <drizzled/catalog/local.h>
 

=== modified file 'drizzled/natural_join_column.cc'
--- drizzled/natural_join_column.cc	2011-03-10 12:49:38 +0000
+++ drizzled/natural_join_column.cc	2011-03-14 16:41:31 +0000
@@ -21,9 +21,9 @@
 #include <drizzled/natural_join_column.h>
 #include <drizzled/table_list.h>
 #include <drizzled/session.h>
+#include <drizzled/sql_lex.h>
 
-namespace drizzled
-{
+namespace drizzled {
 
 Natural_join_column::Natural_join_column(Field *field_param,
                                          TableList *tab)

=== modified file 'drizzled/optimizer/explain_plan.cc'
--- drizzled/optimizer/explain_plan.cc	2011-03-10 12:49:38 +0000
+++ drizzled/optimizer/explain_plan.cc	2011-03-14 16:41:31 +0000
@@ -31,6 +31,7 @@
 #include <drizzled/join.h>
 #include <drizzled/internal/m_string.h>
 #include <drizzled/select_result.h>
+#include <drizzled/sql_lex.h>
 
 #include <cstdio>
 #include <string>

=== modified file 'drizzled/optimizer/quick_group_min_max_select.cc'
--- drizzled/optimizer/quick_group_min_max_select.cc	2011-03-06 17:50:05 +0000
+++ drizzled/optimizer/quick_group_min_max_select.cc	2011-03-14 17:27:03 +0000
@@ -29,6 +29,7 @@
 #include <drizzled/internal/m_string.h>
 #include <drizzled/util/functors.h>
 #include <drizzled/key.h>
+#include <drizzled/table.h>
 
 #include <vector>
 

=== modified file 'drizzled/optimizer/quick_index_merge_select.cc'
--- drizzled/optimizer/quick_index_merge_select.cc	2011-02-24 18:16:42 +0000
+++ drizzled/optimizer/quick_index_merge_select.cc	2011-03-14 16:41:31 +0000
@@ -26,6 +26,7 @@
 #include <drizzled/internal/m_string.h>
 #include <drizzled/unique.h>
 #include <drizzled/key.h>
+#include <drizzled/table.h>
 
 #include <vector>
 

=== modified file 'drizzled/optimizer/quick_range_select.cc'
--- drizzled/optimizer/quick_range_select.cc	2011-03-06 16:34:02 +0000
+++ drizzled/optimizer/quick_range_select.cc	2011-03-14 16:41:31 +0000
@@ -25,6 +25,7 @@
 #include <drizzled/internal/m_string.h>
 #include <drizzled/current_session.h>
 #include <drizzled/key.h>
+#include <drizzled/table.h>
 
 #include <fcntl.h>
 

=== modified file 'drizzled/optimizer/quick_ror_intersect_select.cc'
--- drizzled/optimizer/quick_ror_intersect_select.cc	2011-02-24 18:16:42 +0000
+++ drizzled/optimizer/quick_ror_intersect_select.cc	2011-03-14 16:41:31 +0000
@@ -25,6 +25,7 @@
 #include <drizzled/optimizer/quick_ror_intersect_select.h>
 #include <drizzled/internal/m_string.h>
 #include <drizzled/key.h>
+#include <drizzled/table.h>
 
 #include <vector>
 

=== modified file 'drizzled/optimizer/quick_ror_union_select.cc'
--- drizzled/optimizer/quick_ror_union_select.cc	2011-02-17 10:09:00 +0000
+++ drizzled/optimizer/quick_ror_union_select.cc	2011-03-14 16:41:31 +0000
@@ -23,6 +23,7 @@
 #include <drizzled/optimizer/range.h>
 #include <drizzled/optimizer/quick_range_select.h>
 #include <drizzled/optimizer/quick_ror_union_select.h>
+#include <drizzled/table.h>
 
 #include <vector>
 #include <algorithm>

=== modified file 'drizzled/optimizer/range.cc'
--- drizzled/optimizer/range.cc	2011-03-10 12:49:38 +0000
+++ drizzled/optimizer/range.cc	2011-03-14 17:27:03 +0000
@@ -140,6 +140,7 @@
 #include <drizzled/key.h>
 #include <drizzled/unique.h>
 #include <drizzled/temporal.h> /* Needed in get_mm_leaf() for timestamp -> datetime comparisons */
+#include <drizzled/sql_lex.h>
 
 using namespace std;
 namespace drizzled

=== modified file 'drizzled/parser.cc'
--- drizzled/parser.cc	2011-03-05 14:41:11 +0000
+++ drizzled/parser.cc	2011-03-14 17:27:03 +0000
@@ -24,6 +24,7 @@
 #include <drizzled/alter_info.h>
 #include <drizzled/alter_drop.h>
 #include <drizzled/item/subselect.h>
+#include <drizzled/sql_lex.h>
 
 namespace drizzled {
 namespace parser {

=== modified file 'drizzled/plugin/client/cached.h'
--- drizzled/plugin/client/cached.h	2011-03-14 05:40:28 +0000
+++ drizzled/plugin/client/cached.h	2011-03-14 16:41:31 +0000
@@ -18,23 +18,16 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-
 #pragma once
 
-
+#include <drizzled/field.h>
 #include <drizzled/plugin/client/concurrent.h>
 #include <drizzled/sql/result_set.h>
-
-#include <boost/scoped_ptr.hpp>
-
 #include <iostream>
 
-namespace drizzled
-{
-namespace plugin
-{
-namespace client
-{
+namespace drizzled {
+namespace plugin {
+namespace client {
 
 class Cached : public Concurrent
 {
@@ -44,7 +37,6 @@
 
 public:
   Cached(sql::ResultSet &rs) :
-    Concurrent(),
     column(0),
     max_column(0),
     _result_set(&rs)
@@ -54,12 +46,11 @@
   virtual bool sendFields(List<Item> *list)
   {
     List<Item>::iterator it(list->begin());
-    Item *item;
 
     column= 0;
     max_column= 0;
 
-    while ((item=it++))
+    while (Item* item= it++)
     {
       SendField field;
       item->make_field(&field);
@@ -72,11 +63,10 @@
 
   virtual void sendError(drizzled::error_t error_code, const char *error_message)
   {
-    sql::Exception tmp(error_message, error_code);
-    _result_set->pushException(tmp);
+    _result_set->pushException(sql::Exception(error_message, error_code));
   }
 
-  virtual void checkRowEnd(void)
+  virtual void checkRowEnd()
   {
     if (++column % max_column == 0)
     {
@@ -98,7 +88,7 @@
     return store(str.ptr(), str.length());
   }
 
-  virtual bool store(void)
+  virtual bool store()
   {
     _result_set->setColumnNull(currentColumn());
 
@@ -109,10 +99,7 @@
 
   virtual bool store(int32_t from)
   {
-    std::string tmp;
-
-    tmp= boost::lexical_cast<std::string>(from);
-    _result_set->setColumn(currentColumn(), tmp);
+    _result_set->setColumn(currentColumn(), boost::lexical_cast<std::string>(from));
     checkRowEnd();
 
     return false;
@@ -120,10 +107,7 @@
 
   virtual bool store(uint32_t from)
   {
-    std::string tmp;
-
-    tmp= boost::lexical_cast<std::string>(from);
-    _result_set->setColumn(currentColumn(), tmp);
+    _result_set->setColumn(currentColumn(), boost::lexical_cast<std::string>(from));
     checkRowEnd();
 
     return false;
@@ -131,10 +115,7 @@
 
   virtual bool store(int64_t from)
   {
-    std::string tmp;
-
-    tmp= boost::lexical_cast<std::string>(from);
-    _result_set->setColumn(currentColumn(), tmp);
+    _result_set->setColumn(currentColumn(), boost::lexical_cast<std::string>(from));
     checkRowEnd();
 
     return false;
@@ -142,10 +123,7 @@
 
   virtual bool store(uint64_t from)
   {
-    std::string tmp;
-
-    tmp= boost::lexical_cast<std::string>(from);
-    _result_set->setColumn(currentColumn(), tmp);
+    _result_set->setColumn(currentColumn(), boost::lexical_cast<std::string>(from));
     checkRowEnd();
 
     return false;

=== modified file 'drizzled/plugin/table_function.cc'
--- drizzled/plugin/table_function.cc	2011-03-10 13:40:36 +0000
+++ drizzled/plugin/table_function.cc	2011-03-14 17:27:03 +0000
@@ -26,11 +26,11 @@
 #include <drizzled/session.h>
 #include <drizzled/show.h>
 #include <drizzled/table_function_container.h>
+#include <drizzled/sql_lex.h>
 
 #include <vector>
 
-namespace drizzled
-{
+namespace drizzled {
 
 static TableFunctionContainer table_functions;
 

=== modified file 'drizzled/select_send.h'
--- drizzled/select_send.h	2011-03-14 05:40:28 +0000
+++ drizzled/select_send.h	2011-03-14 17:27:03 +0000
@@ -24,6 +24,7 @@
 #include <drizzled/plugin/query_cache.h>
 #include <drizzled/plugin/transactional_storage_engine.h>
 #include <drizzled/select_result.h>
+#include <drizzled/sql_lex.h>
 
 namespace drizzled
 {

=== modified file 'drizzled/select_subselect.h'
--- drizzled/select_subselect.h	2011-03-14 05:40:28 +0000
+++ drizzled/select_subselect.h	2011-03-14 17:27:03 +0000
@@ -20,6 +20,7 @@
 
 #pragma once
 
+#include <drizzled/item/subselect.h>
 #include <drizzled/select_result_interceptor.h>
 
 namespace drizzled

=== modified file 'drizzled/session.cc'
--- drizzled/session.cc	2011-03-12 15:07:12 +0000
+++ drizzled/session.cc	2011-03-14 17:27:03 +0000
@@ -70,6 +70,7 @@
 #include <plugin/myisam/myisam.h>
 #include <drizzled/item/subselect.h>
 #include <drizzled/statement.h>
+#include <drizzled/sql_lex.h>
 
 #include <algorithm>
 #include <climits>
@@ -144,6 +145,14 @@
 
 class Session::impl_c
 {
+public:
+  /**
+    The lex to hold the parsed tree of conventional (non-prepared) queries.
+    Whereas for prepared and stored procedure statements we use an own lex
+    instance for each new query, for conventional statements we reuse
+    the same lex. (@see mysql_parse for details).
+  */
+  LEX lex;
 };
 
 Session::Session(plugin::Client *client_arg, catalog::Instance::shared_ptr catalog_arg) :
@@ -195,6 +204,7 @@
   m_lip(NULL),
   cached_table(0),
   arg_of_last_insert_id_function(false),
+  impl_(new impl_c),
   _catalog(catalog_arg),
   transaction_message(NULL),
   statement_message(NULL),
@@ -259,6 +269,21 @@
   plugin::EventObserver::registerSessionEvents(*this);
 }
 
+const LEX& Session::lex() const
+{
+  return impl_->lex;
+}
+
+LEX& Session::lex()
+{
+  return impl_->lex;
+}
+
+enum_sql_command Session::getSqlCommand() const
+{
+  return lex().sql_command;
+}
+
 void statement::Statement::set_command(enum_sql_command v)
 {
 	session().lex().sql_command= v;

=== modified file 'drizzled/session.h'
--- drizzled/session.h	2011-03-14 05:40:28 +0000
+++ drizzled/session.h	2011-03-14 15:53:42 +0000
@@ -41,7 +41,6 @@
 #include <drizzled/file_exchange.h>
 #include <drizzled/ha_data.h>
 #include <drizzled/identifier.h>
-#include <drizzled/lex_column.h>
 #include <drizzled/named_savepoint.h>
 #include <drizzled/open_tables_state.h>
 #include <drizzled/plugin.h>
@@ -86,7 +85,12 @@
 }
 
 namespace internal { struct st_my_thread_var; }
-namespace table { class Placeholder; }
+
+namespace table 
+{ 
+  class Placeholder; 
+  class Singular; 
+}
 
 class CopyField;
 class DrizzleXid;
@@ -204,20 +208,9 @@
   }
 
 public:
-  const LEX& lex() const
-  {
-    return main_lex;
-  }
-
-  LEX& lex()
-  {
-    return main_lex;
-  }
-
-  enum_sql_command getSqlCommand() const
-  {
-    return lex().sql_command;
-  }
+  const LEX& lex() const;
+  LEX& lex();
+  enum_sql_command getSqlCommand() const;
 
   /** query associated with this statement */
   typedef boost::shared_ptr<const std::string> QueryString;
@@ -1386,13 +1379,6 @@
   /** The current internal error handler for this thread, or NULL. */
   Internal_error_handler *m_internal_handler;
   /**
-    The lex to hold the parsed tree of conventional (non-prepared) queries.
-    Whereas for prepared and stored procedure statements we use an own lex
-    instance for each new query, for conventional statements we reuse
-    the same lex. (@see mysql_parse for details).
-  */
-  LEX main_lex;
-  /**
     This memory root is used for two purposes:
     - for conventional queries, to allocate structures stored in main_lex
     during parsing, and allocate runtime data (execution plan, etc.)

=== modified file 'drizzled/set_var.cc'
--- drizzled/set_var.cc	2011-03-11 19:18:45 +0000
+++ drizzled/set_var.cc	2011-03-14 17:27:03 +0000
@@ -27,6 +27,7 @@
 #include <drizzled/session.h>
 #include <drizzled/item/string.h>
 #include <drizzled/function/set_user_var.h>
+#include <drizzled/sql_lex.h>
 
 using namespace std;
 

=== modified file 'drizzled/show.cc'
--- drizzled/show.cc	2011-03-10 13:07:29 +0000
+++ drizzled/show.cc	2011-03-14 17:27:03 +0000
@@ -29,11 +29,10 @@
 #include <drizzled/session.h>
 #include <drizzled/show.h>
 #include <drizzled/sql_select.h>
-
 #include <drizzled/statement/show.h>
 #include <drizzled/statement/show_errors.h>
 #include <drizzled/statement/show_warnings.h>
-
+#include <drizzled/sql_lex.h>
 
 #include <sys/stat.h>
 

=== modified file 'drizzled/sql_base.cc'
--- drizzled/sql_base.cc	2011-03-10 12:49:38 +0000
+++ drizzled/sql_base.cc	2011-03-14 17:27:03 +0000
@@ -59,6 +59,7 @@
 #include <drizzled/plugin/storage_engine.h>
 #include <drizzled/session.h>
 #include <drizzled/item/subselect.h>
+#include <drizzled/sql_lex.h>
 
 #include <drizzled/refresh_version.h>
 

=== modified file 'drizzled/sql_delete.cc'
--- drizzled/sql_delete.cc	2011-03-10 13:40:36 +0000
+++ drizzled/sql_delete.cc	2011-03-14 17:27:03 +0000
@@ -31,6 +31,7 @@
 #include <drizzled/internal/iocache.h>
 #include <drizzled/transaction_services.h>
 #include <drizzled/filesort.h>
+#include <drizzled/sql_lex.h>
 
 namespace drizzled
 {

=== modified file 'drizzled/sql_error.cc'
--- drizzled/sql_error.cc	2011-03-10 12:49:38 +0000
+++ drizzled/sql_error.cc	2011-03-14 17:27:03 +0000
@@ -51,6 +51,7 @@
 #include <drizzled/item/empty_string.h>
 #include <drizzled/item/return_int.h>
 #include <drizzled/plugin/client.h>
+#include <drizzled/sql_lex.h>
 
 using namespace std;
 

=== modified file 'drizzled/sql_insert.cc'
--- drizzled/sql_insert.cc	2011-03-10 13:40:36 +0000
+++ drizzled/sql_insert.cc	2011-03-14 17:27:03 +0000
@@ -36,6 +36,7 @@
 #include <drizzled/table/shell.h>
 #include <drizzled/alter_info.h>
 #include <drizzled/sql_parse.h>
+#include <drizzled/sql_lex.h>
 
 namespace drizzled
 {

=== modified file 'drizzled/sql_lex.cc'
--- drizzled/sql_lex.cc	2011-03-10 13:40:36 +0000
+++ drizzled/sql_lex.cc	2011-03-14 17:27:03 +0000
@@ -32,6 +32,7 @@
 #include <drizzled/select_result.h>
 #include <drizzled/item/subselect.h>
 #include <drizzled/statement.h>
+#include <drizzled/sql_lex.h>
 
 #include <cstdio>
 #include <ctype.h>

=== modified file 'drizzled/sql_load.cc'
--- drizzled/sql_load.cc	2011-03-10 12:49:38 +0000
+++ drizzled/sql_load.cc	2011-03-14 17:27:03 +0000
@@ -27,6 +27,7 @@
 #include <drizzled/internal/my_sys.h>
 #include <drizzled/internal/iocache.h>
 #include <drizzled/plugin/storage_engine.h>
+#include <drizzled/sql_lex.h>
 
 #include <sys/stat.h>
 #include <fcntl.h>

=== modified file 'drizzled/sql_update.cc'
--- drizzled/sql_update.cc	2011-03-10 12:49:38 +0000
+++ drizzled/sql_update.cc	2011-03-14 17:27:03 +0000
@@ -34,6 +34,7 @@
 #include <drizzled/filesort.h>
 #include <drizzled/plugin/storage_engine.h>
 #include <drizzled/key.h>
+#include <drizzled/sql_lex.h>
 
 #include <boost/dynamic_bitset.hpp>
 #include <list>

=== modified file 'drizzled/statement/alter_schema.cc'
--- drizzled/statement/alter_schema.cc	2011-03-10 10:44:18 +0000
+++ drizzled/statement/alter_schema.cc	2011-03-14 17:27:03 +0000
@@ -25,6 +25,7 @@
 #include <drizzled/plugin/storage_engine.h>
 #include <drizzled/schema.h>
 #include <drizzled/message.h>
+#include <drizzled/sql_lex.h>
 
 #include <string>
 

=== modified file 'drizzled/statement/analyze.cc'
--- drizzled/statement/analyze.cc	2011-03-10 10:44:18 +0000
+++ drizzled/statement/analyze.cc	2011-03-14 17:27:03 +0000
@@ -23,6 +23,7 @@
 #include <drizzled/session.h>
 #include <drizzled/statement/analyze.h>
 #include <drizzled/sql_table.h>
+#include <drizzled/sql_lex.h>
 
 namespace drizzled
 {

=== modified file 'drizzled/statement/change_schema.cc'
--- drizzled/statement/change_schema.cc	2011-03-10 10:44:18 +0000
+++ drizzled/statement/change_schema.cc	2011-03-14 17:27:03 +0000
@@ -23,6 +23,7 @@
 #include <drizzled/session.h>
 #include <drizzled/statement/change_schema.h>
 #include <drizzled/schema.h>
+#include <drizzled/sql_lex.h>
 
 #include <string>
 

=== modified file 'drizzled/statement/check.cc'
--- drizzled/statement/check.cc	2011-03-10 10:44:18 +0000
+++ drizzled/statement/check.cc	2011-03-14 17:27:03 +0000
@@ -23,6 +23,7 @@
 #include <drizzled/session.h>
 #include <drizzled/statement/check.h>
 #include <drizzled/sql_table.h>
+#include <drizzled/sql_lex.h>
 
 namespace drizzled
 {

=== modified file 'drizzled/statement/create_schema.cc'
--- drizzled/statement/create_schema.cc	2011-03-10 10:44:18 +0000
+++ drizzled/statement/create_schema.cc	2011-03-14 17:27:03 +0000
@@ -27,6 +27,7 @@
 #include <drizzled/plugin/event_observer.h>
 #include <drizzled/message.h>
 #include <drizzled/plugin/storage_engine.h>
+#include <drizzled/sql_lex.h>
 
 #include <string>
 

=== modified file 'drizzled/statement/create_table.h'
--- drizzled/statement/create_table.h	2011-03-14 05:40:28 +0000
+++ drizzled/statement/create_table.h	2011-03-14 17:27:03 +0000
@@ -23,13 +23,13 @@
 #include <drizzled/alter_info.h>
 #include <drizzled/statement.h>
 #include <drizzled/foreign_key.h>
-
-namespace drizzled
-{
+#include <drizzled/sql_lex.h>
+
+namespace drizzled {
+
 class Session;
 
-namespace statement
-{
+namespace statement {
 
 class CreateTable : public Statement
 {

=== modified file 'drizzled/statement/delete.cc'
--- drizzled/statement/delete.cc	2011-03-10 10:44:18 +0000
+++ drizzled/statement/delete.cc	2011-03-14 17:27:03 +0000
@@ -24,6 +24,7 @@
 #include <drizzled/lock.h>
 #include <drizzled/probes.h>
 #include <drizzled/statement/delete.h>
+#include <drizzled/sql_lex.h>
 
 namespace drizzled
 {

=== modified file 'drizzled/statement/drop_schema.cc'
--- drizzled/statement/drop_schema.cc	2011-03-10 10:44:18 +0000
+++ drizzled/statement/drop_schema.cc	2011-03-14 17:27:03 +0000
@@ -24,7 +24,7 @@
 #include <drizzled/session.h>
 #include <drizzled/statement/drop_schema.h>
 #include <drizzled/plugin/event_observer.h>
-
+#include <drizzled/sql_lex.h>
 #include <drizzled/schema.h>
 
 #include <string>

=== modified file 'drizzled/statement/drop_table.cc'
--- drizzled/statement/drop_table.cc	2011-03-10 10:44:18 +0000
+++ drizzled/statement/drop_table.cc	2011-03-14 17:27:03 +0000
@@ -24,6 +24,7 @@
 #include <drizzled/lock.h>
 #include <drizzled/statement/drop_table.h>
 #include <drizzled/sql_table.h>
+#include <drizzled/sql_lex.h>
 
 namespace drizzled
 {

=== modified file 'drizzled/statement/execute.cc'
--- drizzled/statement/execute.cc	2011-03-10 10:44:18 +0000
+++ drizzled/statement/execute.cc	2011-03-14 17:27:03 +0000
@@ -28,6 +28,7 @@
 #include <drizzled/plugin/client.h>
 #include <drizzled/plugin/null_client.h>
 #include <drizzled/plugin/client/concurrent.h>
+#include <drizzled/sql_lex.h>
 
 namespace drizzled
 {

=== modified file 'drizzled/table/shell.h'
--- drizzled/table/shell.h	2011-03-14 05:40:28 +0000
+++ drizzled/table/shell.h	2011-03-14 17:27:03 +0000
@@ -20,11 +20,10 @@
 
 #pragma once
 
-namespace drizzled
-{
+#include <drizzled/table.h>
 
-namespace table
-{
+namespace drizzled {
+namespace table {
 
 class Shell : public drizzled::Table
 {
@@ -32,21 +31,16 @@
 
 public:
   Shell(TableShare &arg) :
-    Table(),
     _share(arg)
   {
   }
 
-  ~Shell()
-  {
-  }
-
   const TableShare *getShare() const { return &_share; } /* Get rid of this long term */
   TableShare *getMutableShare() { return &_share; } /* Get rid of this long term */
   bool hasShare() const { return true; } /* Get rid of this long term */
   void setShare(TableShare *) { ; } /* Get rid of this long term */
 
-  void release() { assert(0); }; // This should never happen
+  void release() { assert(false); }; // This should never happen
 
 };
 

=== modified file 'libdrizzle/conn.c'
--- libdrizzle/conn.c	2011-03-07 15:13:11 +0000
+++ libdrizzle/conn.c	2011-03-14 16:58:11 +0000
@@ -792,11 +792,11 @@
     memset(&ai, 0, sizeof(struct addrinfo));
     ai.ai_socktype= SOCK_STREAM;
     ai.ai_protocol= IPPROTO_TCP;
+    ai.ai_flags = AI_PASSIVE;
+    ai.ai_family = AF_UNSPEC;
 
     if (con->options & DRIZZLE_CON_LISTEN)
     {
-      ai.ai_flags = AI_PASSIVE;
-      ai.ai_family = AF_UNSPEC;
       host= tcp->host;
     }
     else

=== modified file 'libdrizzle/include.am'
--- libdrizzle/include.am	2011-03-09 04:38:08 +0000
+++ libdrizzle/include.am	2011-03-15 01:33:33 +0000
@@ -98,7 +98,7 @@
 examples_sqlite_server_SOURCES= examples/sqlite_server.c
 endif
 
-nobase_dist_include_HEADERS+= \
+nobase_dist_libdrizzleinclude_HEADERS= \
 	libdrizzle/column.h \
 	libdrizzle/column_client.h \
 	libdrizzle/column_server.h \
@@ -143,8 +143,8 @@
 install-libdrizzle:
 	test -z "$(libdir)" || $(MKDIR_P) "$(DESTDIR)$(libdir)"
 	$(LIBTOOL) $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=install $(INSTALL) $(INSTALL_STRIP_FLAG) libdrizzle/libdrizzle.la "$(DESTDIR)$(libdir)"
-	test -z "$(includedir)" || $(MKDIR_P) "$(DESTDIR)$(includedir)"
-	@list='$(nobase_dist_include_HEADERS)'; test -n "$(includedir)" || list=; \
+	test -z "$(libdrizzleincludedir)" || $(MKDIR_P) "$(DESTDIR)$(libdrizzleincludedir)"
+	@list='$(nobase_dist_libdrizzleinclude_HEADERS)'; test -n "$(libdrizzleincludedir)" || list=; \
 	$(am__nobase_list) | while read dir files; do \
           if test "x$$dir" = "xlibdrizzle" ; then \
 	    xfiles=; for file in $$files; do \
@@ -152,9 +152,9 @@
 	      else xfiles="$$xfiles $(srcdir)/$$file"; fi; done; \
 	    test -z "$$xfiles" || { \
 	      test "x$$dir" = x. || { \
-	        echo "$(MKDIR_P) '$(DESTDIR)$(includedir)/$$dir'"; \
-	        $(MKDIR_P) "$(DESTDIR)$(includedir)/$$dir"; }; \
-	      echo " $(INSTALL_HEADER) $$xfiles '$(DESTDIR)$(includedir)/$$dir'"; \
-	      $(INSTALL_HEADER) $$xfiles "$(DESTDIR)$(includedir)/$$dir" || exit $$?; }; \
+	        echo "$(MKDIR_P) '$(DESTDIR)$(libdrizzleincludedir)/$$dir'"; \
+	        $(MKDIR_P) "$(DESTDIR)$(libdrizzleincludedir)/$$dir"; }; \
+	      echo " $(INSTALL_HEADER) $$xfiles '$(DESTDIR)$(libdrizzleincludedir)/$$dir'"; \
+	      $(INSTALL_HEADER) $$xfiles "$(DESTDIR)$(libdrizzleincludedir)/$$dir" || exit $$?; }; \
           fi; \
 	done

=== modified file 'libdrizzle/query.c'
--- libdrizzle/query.c	2011-03-01 14:20:40 +0000
+++ libdrizzle/query.c	2011-03-14 16:54:30 +0000
@@ -348,9 +348,9 @@
   return DRIZZLE_RETURN_OK;
 }
 
-size_t drizzle_escape_string(char *to, const char *from, size_t from_size)
+ssize_t drizzle_safe_escape_string(char *to, size_t max_to_size, const char *from, size_t from_size)
 {
-  size_t to_size= 0;
+  ssize_t to_size= 0;
   char newchar;
   const char *end;
 
@@ -389,12 +389,18 @@
     }
     if (newchar != '\0')
     {
+      if ((size_t)to_size + 2 > max_to_size)
+        return -1;
+
       *to++= '\\';
       *to++= newchar;
       to_size++;
     }
     else
-    { 
+    {
+      if ((size_t)to_size + 1 > max_to_size)
+        return -1;
+
       *to++= *from;
     }
     to_size++;
@@ -405,6 +411,11 @@
   return to_size;
 }
 
+size_t drizzle_escape_string(char *to, const char *from, size_t from_size)
+{
+  return (size_t) drizzle_safe_escape_string(to, (from_size * 2), from, from_size);
+}
+
 size_t drizzle_hex_string(char *to, const char *from, size_t from_size)
 {
   static const char hex_map[]= "0123456789ABCDEF";

=== modified file 'libdrizzle/query.h'
--- libdrizzle/query.h	2010-12-12 11:52:00 +0000
+++ libdrizzle/query.h	2011-03-14 16:54:30 +0000
@@ -230,6 +230,8 @@
 DRIZZLE_API
 size_t drizzle_escape_string(char *to, const char *from, size_t from_size);
 DRIZZLE_API
+ssize_t drizzle_safe_escape_string(char *to, size_t max_to_size, const char *from, size_t from_size);
+DRIZZLE_API
 size_t drizzle_hex_string(char *to, const char *from, size_t from_size);
 DRIZZLE_API
 void drizzle_mysql_password_hash(char *to, const char *from, size_t from_size);

=== modified file 'plugin/console/console.cc'
--- plugin/console/console.cc	2011-02-23 17:21:37 +0000
+++ plugin/console/console.cc	2011-03-14 15:00:51 +0000
@@ -14,6 +14,7 @@
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 #include <config.h>
+#include <drizzled/field.h>
 #include <drizzled/gettext.h>
 #include <drizzled/plugin/listen_tcp.h>
 #include <drizzled/plugin/client.h>

=== modified file 'plugin/function_engine/cursor.cc'
--- plugin/function_engine/cursor.cc	2011-02-22 10:26:02 +0000
+++ plugin/function_engine/cursor.cc	2011-03-14 15:00:51 +0000
@@ -24,6 +24,7 @@
 #include <drizzled/session.h>
 #include <drizzled/internal/my_sys.h>
 #include <drizzled/field/blob.h>
+#include <drizzled/table.h>
 
 #include <unistd.h>
 #include <fcntl.h>

=== modified file 'plugin/haildb/haildb_engine.cc'
--- plugin/haildb/haildb_engine.cc	2011-03-11 19:18:45 +0000
+++ plugin/haildb/haildb_engine.cc	2011-03-14 15:00:51 +0000
@@ -107,8 +107,8 @@
 #include <drizzled/module/option_map.h>
 #include <drizzled/charset.h>
 #include <drizzled/current_session.h>
-
 #include <drizzled/key.h>
+#include <drizzled/sql_lex.h>
 
 #include <iostream>
 

=== modified file 'plugin/hello_events/hello_events.cc'
--- plugin/hello_events/hello_events.cc	2011-02-17 00:14:13 +0000
+++ plugin/hello_events/hello_events.cc	2011-03-14 15:00:51 +0000
@@ -35,8 +35,10 @@
 #include <string>
 #include <cstdio>
 #include <boost/program_options.hpp>
+#include <drizzled/item.h>
 #include <drizzled/module/option_map.h>
 #include <drizzled/session.h>
+#include <drizzled/table/instance/base.h>
 #include "hello_events.h"
 
 namespace po= boost::program_options;

=== modified file 'plugin/logging_stats/logging_stats.cc'
--- plugin/logging_stats/logging_stats.cc	2011-03-10 12:49:38 +0000
+++ plugin/logging_stats/logging_stats.cc	2011-03-14 15:00:51 +0000
@@ -94,6 +94,7 @@
 #include <boost/program_options.hpp>
 #include <drizzled/module/option_map.h>
 #include <drizzled/session.h>
+#include <drizzled/sql_lex.h>
 
 namespace po= boost::program_options;
 using namespace drizzled;

=== modified file 'plugin/pbms/src/engine_ms.h'
--- plugin/pbms/src/engine_ms.h	2011-03-14 05:40:28 +0000
+++ plugin/pbms/src/engine_ms.h	2011-03-14 15:00:51 +0000
@@ -32,8 +32,8 @@
 #define __ENGINE_MS_H__
 
 #include "defs_ms.h"
-
 #include "pbms.h"
+
 class MSOpenTable;
 
 #ifdef DRIZZLED

=== modified file 'plugin/pbms/src/events_ms.cc'
--- plugin/pbms/src/events_ms.cc	2011-02-21 16:33:37 +0000
+++ plugin/pbms/src/events_ms.cc	2011-03-14 15:00:51 +0000
@@ -25,6 +25,7 @@
 
 #include <drizzled/session.h>
 #include <drizzled/field/blob.h>
+#include <drizzled/sql_lex.h>
 
 #include "cslib/CSConfig.h"
 #include "cslib/CSGlobal.h"

=== modified file 'plugin/pbms/src/parameters_ms.cc'
--- plugin/pbms/src/parameters_ms.cc	2011-02-17 00:14:13 +0000
+++ plugin/pbms/src/parameters_ms.cc	2011-03-14 15:00:51 +0000
@@ -30,6 +30,7 @@
 #include <drizzled/common.h>
 #include <drizzled/plugin.h>
 #include <drizzled/session.h>
+#include <drizzled/sql_lex.h>
 
 
 #define my_strdup(a,b) strdup(a)

=== modified file 'plugin/slave/docs/user_example.rst'
--- plugin/slave/docs/user_example.rst	2011-03-09 00:07:51 +0000
+++ plugin/slave/docs/user_example.rst	2011-03-14 20:08:52 +0000
@@ -1,26 +1,26 @@
 How to use replication: An example
 ====================================
 
-This page covers how to complete a simple replication setup between two Drizzle servers using the replication slave plugin. Some of the concepts are very similar to MySQL replication. This is the simplest of examples (single master, single slave), with additional explanation on how to provision a new slave into an existing setup.
+Simple replication setup (using a single master and a single slave) between two Drizzle servers is straightforward with the replication slave plugin. With Drizzle replication, you can also provision a new slave into an existing setup.
 
-Replication setup begins with making certain that both master and slave share the same version of Drizzle to avoid any potential incompatibility issues. Then you set up the master.
+Replication setup begins with making certain that both master and slave share the same version of Drizzle to avoid any potential incompatibility issues.
 
 Master Setup
 -------------
 
-Setting up the master is the easiest step. The only real requirement for this step is to make sure that the master Drizzle database server is started with the --innodb.replication-log option. This will look something like:
+Setting up the master is the first step. An important requirement is to start the master Drizzle database server with the --innodb.replication-log option. For example:
 
     master> sbin/drizzled --datadir=$PWD/var --innodb.replication-log &
 
 
-For more complex setups, you'll also want to consider using the --server-id option, but the default is fine for this example. That option is documented here.
+For more complex setups, the --server-id option may be appropriate to use.
 
-With the master running, you can optionally now create a backup of any databases to be imported on the new slave. You would use :doc:`../../clients/drizzledump` to make such a backup. For the sake of simplicity, this example assumes that we are starting with a fresh database with no data.
+With the master running, you can optionally now create a backup of any databases to be imported on the new slave by using :doc:`../../clients/drizzledump`. This example, however, assumes that we are starting with a fresh database with no data.
 
 Slave Setup
 -------------
 
-Once the master is running, the next step is to set up the slave. Starting the slave is almost as simple as starting the master. There are two Drizzle database server options required for the slave: --plugin-add=slave and --slave.config-file. This will look something like: ::
+Starting the slave is almost as simple as starting the master. There are two Drizzle database server options required for the slave: --plugin-add=slave and --slave.config-file. For example: ::
 
 	slave> sbin/drizzled --datadir=$PWD/var \
                                     --plugin-add=slave \
@@ -29,21 +29,19 @@
 
 These options tell the server to load the slave plugin, and then tell the slave plugin where to find the slave host configuration file. This configuration file has options to specify the master host and a few options to control how the slave operates. You can read more about the available configuration options in the replication slave plugin documentation. Below is a simple example: ::
 
-	master-host = kodiak
+	master-host = dino
 	master-port = 3306
-	master-user = kodiak_slave
+	master-user = dino_slave
 	master-pass = my_password
 	io-thread-sleep = 10
 	applier-thread-sleep = 10
 
-Most of these options have sensible defaults, and it should be pretty obvious what most of them are for. The plugin documentation referenced above describes them in more complete detail if you need more information.
-
-So once you start the slave as described above, it will immediately connect to the master host specified in the configuration file and begin pulling events from the InnoDB-based transaction log. By default, a freshly provisioned slave will begin pulling from the beginning of this transaction log. Once all replication messages have been pulled from the master and stored locally on the slave host, the IO thread will sleep and periodically awaken to check for more messages. That's all fine and dandy for your first slave machine in a brand new replication setup, but how do you insert another slave host into an already existing replication architecture? I'm glad you asked!
+The slave will immediately connect to the master host specified in the configuration file and begin pulling events from the InnoDB-based transaction log. By default, a freshly provisioned slave will begin pulling from the beginning of this transaction log. Once all replication messages have been pulled from the master and stored locally on the slave host, the IO thread will sleep and periodically awaken to check for more messages. This is straightforward for an initial replication setup. See below to learn about inserting another slave host into an already existing replication architecture.
 
 Provisioning a New Slave Host
 -------------------------------
 
-Provisioning a new slave host very easy. The basic formula for creating a new slave host for an existing replication setup is:
+The basic formula for creating a new slave host for an existing replication setup is:
 
    1. Make a backup of the master databases.
    2. Record the state of the master transaction log at the point the backup was made.
@@ -61,7 +59,7 @@
 * **COMMIT_ID**:  This value is the commit sequence number recorded for the most recently executed transaction stored in the transaction log. We can use this value to determine proper commit order within the log. The unique transaction ID cannot be used since that value is assigned when the transaction is started, not when it is committed.
 * **ID**:  This is the unique transaction identifier associated with the most recently executed transaction stored in the transaction log.
 
-Next, steps #3 and #4 must be completed to start the new slave. First, you must start the slave WITHOUT the replication slave plugin enabled. We don't want it reading from the master until the backup is imported. To start it without the plugin enabled, import your backup, then shutdown the server: ::
+Next, steps #3 and #4 must be completed to start the new slave. First, you must start the slave WITHOUT the replication slave plugin enabled, to prevent it from reading from the master until the backup is imported. To start it without the plugin enabled, import your backup, then shutdown the server: ::
 
 	slave> sbin/drizzled --datadir=$PWD/var &
 	slave> drizzle < master.backup

=== modified file 'plugin/status_dictionary/status.cc'
--- plugin/status_dictionary/status.cc	2011-02-17 00:14:13 +0000
+++ plugin/status_dictionary/status.cc	2011-03-14 15:00:51 +0000
@@ -26,6 +26,7 @@
 #include <drizzled/internal/m_string.h>
 #include <drizzled/definitions.h>
 #include <drizzled/status_helper.h>
+#include <drizzled/sql_lex.h>
 
 #include <vector>
 #include <string>

=== modified file 'plugin/table_cache_dictionary/table_cache.cc'
--- plugin/table_cache_dictionary/table_cache.cc	2011-03-07 12:31:41 +0000
+++ plugin/table_cache_dictionary/table_cache.cc	2011-03-14 15:00:51 +0000
@@ -21,6 +21,7 @@
 #include <config.h>
 
 #include <plugin/table_cache_dictionary/dictionary.h>
+#include <drizzled/table.h>
 #include <drizzled/pthread_globals.h>
 
 using namespace drizzled;

=== modified file 'plugin/utility_dictionary/counter.cc'
--- plugin/utility_dictionary/counter.cc	2011-03-10 11:49:38 +0000
+++ plugin/utility_dictionary/counter.cc	2011-03-14 16:41:31 +0000
@@ -24,7 +24,7 @@
 
 #include <drizzled/atomics.h>
 #include <drizzled/session.h>
-
+#include <drizzled/sql_lex.h>
 
 using namespace drizzled;
 using namespace std;

=== modified file 'plugin/utility_dictionary/random_number.cc'
--- plugin/utility_dictionary/random_number.cc	2011-03-10 11:49:38 +0000
+++ plugin/utility_dictionary/random_number.cc	2011-03-14 16:41:31 +0000
@@ -24,7 +24,7 @@
 
 #include <drizzled/atomics.h>
 #include <drizzled/session.h>
-
+#include <drizzled/sql_lex.h>
 
 using namespace drizzled;
 using namespace std;

=== modified file 'plugin/utility_dictionary/random_string.cc'
--- plugin/utility_dictionary/random_string.cc	2011-03-10 11:49:38 +0000
+++ plugin/utility_dictionary/random_string.cc	2011-03-14 16:41:31 +0000
@@ -24,7 +24,7 @@
 
 #include <drizzled/atomics.h>
 #include <drizzled/session.h>
-
+#include <drizzled/sql_lex.h>
 
 using namespace drizzled;
 using namespace std;

=== modified file 'support-files/include.am'
--- support-files/include.am	2011-02-11 23:32:44 +0000
+++ support-files/include.am	2011-03-14 16:52:13 +0000
@@ -26,4 +26,4 @@
 pkgconfigdir= $(libdir)/pkgconfig
 pkgconfig_DATA= \
 		support-files/drizzle7.pc \
-		support-files/libdrizzle.pc
+		support-files/libdrizzle-1.0.pc

=== renamed file 'support-files/libdrizzle.pc.in' => 'support-files/libdrizzle-1.0.pc.in'
--- support-files/libdrizzle.pc.in	2011-02-11 22:57:37 +0000
+++ support-files/libdrizzle-1.0.pc.in	2011-03-14 17:03:29 +0000
@@ -2,9 +2,10 @@
 exec_prefix=@exec_prefix@
 libdir=@libdir@
 includedir=@includedir@
+libdrizzleincludedir=@libdrizzleincludedir@
 
 Name: libdrizzle
 Description: Drizzle Client & Protocol Library
-Version: @VERSION@
+Version: @PANDORA_RELEASE_VERSION@
 Libs: -L${libdir} -ldrizzle
-Cflags: -I${includedir}
+Cflags: -I${libdrizzleincludedir}

=== modified file 'unittests/libdrizzle_test.cc'
--- unittests/libdrizzle_test.cc	2011-03-01 14:20:40 +0000
+++ unittests/libdrizzle_test.cc	2011-03-14 16:54:30 +0000
@@ -51,6 +51,28 @@
   BOOST_REQUIRE_EQUAL("\\0\1\2\3\4\5", out);
 }
 
+BOOST_AUTO_TEST_CASE(drizzleSafeEscapeString)
+{
+  const char* orig= "hello \"world\"\n";
+  char out[255];
+  ssize_t out_len;
+
+  out_len= drizzle_safe_escape_string(out, 255, orig, strlen(orig));
+
+  BOOST_REQUIRE_EQUAL(17, out_len);
+  BOOST_REQUIRE_EQUAL("hello \\\"world\\\"\\n", out);
+}
+
+BOOST_AUTO_TEST_CASE(drizzleSafeEscapeStringFail)
+{
+  const char* orig= "hello \"world\"\n";
+  char out[5];
+  ssize_t out_len;
+
+  out_len= drizzle_safe_escape_string(out, 5, orig, strlen(orig));
+
+  BOOST_REQUIRE_EQUAL(-1, out_len);
+}
 
 BOOST_AUTO_TEST_CASE(drizzleHexString)
 {

